@@ -8,10 +8,11 @@ import numpy as np
 import matplotlib.pyplot as plt
 from itertools import chain, count
 
-def barscatter(data, transpose = False, unequal=False,
+def barscatter(data, transpose = False,
                 groupwidth = .75,
                 barwidth = .8,
                 paired = False,
+                unequal = False,
                 spaced = False,
                 yspace = 20,
                 xspace = 0.1,
@@ -28,7 +29,7 @@ def barscatter(data, transpose = False, unequal=False,
                 scattersize = 80,
                 scatteralpha = 1,
                 spreadscatters = False,
-                linewidth=0.5,
+                linewidth=0.75,
                 xlim=[],
                 ylim=[],
                 ylabel = 'none',
@@ -50,6 +51,7 @@ def barscatter(data, transpose = False, unequal=False,
         data - Required. Should be a list (or list of lists) or an array. Will try to convert if needed.
         barwidth - width if bars, default=0.9
         paired - attempts to add lines between paired data points, default=False
+        unequal - Boolean, set to True if groups are unequal, default=False
         spaced - spaces out data points so that they are not at an identical x value, default=False
         yspace - used in conjunction with spaced to determine spacing of data points, defalt=20
         xspace - used in conjunction with spaced to determine spacing of data points, defalt=0.1
@@ -66,7 +68,7 @@ def barscatter(data, transpose = False, unequal=False,
         scattersize - size of datapoints, default=80
         scatteralpha -sets opacity of scatter points, default=1
         spreadscatters - to be checked!
-        linewidth - width of lines, default=1
+        linewidth - width of lines, default=0.75
         xlim - sets x limits, default=[]
         ylim - sets y limits, default=[]
         ylabel - sets y axis label, default='none'
@@ -92,20 +94,20 @@ def barscatter(data, transpose = False, unequal=False,
 
     if unequal == True:
         dims = np.ndim(data)
-        data_obj = np.ndarray((np.shape(data)), dtype=np.object)
+        data_obj = np.ndarray((np.shape(data)), dtype=object)
         if dims == 1:
             for i, dim in enumerate(data):
-                data_obj[i] = np.array(dim, dtype=np.object)
+                data_obj[i] = np.array(dim, dtype=object)
             data = data_obj
         elif dims == 2:            
             for i1, dim1 in enumerate(data):
                 for i2, dim2 in enumerate(dim1):
-                    data_obj[i1][i2] = np.array(dim2, dtype=np.object)
+                    data_obj[i1][i2] = np.array(dim2, dtype=object)
             data = data_obj
         else:
             print('Cannot convert that number of dimensions or data is in wrong format. Attmepting to make graph assuming equal groups.')
     
-    if type(data) != np.ndarray or data.dtype != np.object:
+    if type(data) != np.ndarray or data.dtype != object:
         dims = np.shape(data)
         if len(dims) == 2 or len(dims) == 1:
             data = data2obj1D(data)
@@ -183,7 +185,8 @@ def barscatter(data, transpose = False, unequal=False,
         barx.append(x)
         barlist.append(ax.bar(x, y, barwidth,
                          facecolor = bfc, edgecolor = bec,
-                         zorder=-1))
+                         zorder=-1,
+                         linewidth=linewidth))
     
     # Uncomment these lines to show method for changing bar colors outside of
     # function using barlist properties
@@ -206,6 +209,7 @@ def barscatter(data, transpose = False, unequal=False,
                 sclist.append(ax.scatter(xVals, yVals, s = scattersize,
                              c = scf,
                              edgecolors = sce,
+                             linewidth=linewidth,
                              zorder=20,
                              clip_on=False))
                          
@@ -214,6 +218,7 @@ def barscatter(data, transpose = False, unequal=False,
                      sclist.append(ax.scatter(x, y, s = scattersize,
                                      c = scf,
                                      edgecolors = sce,
+                                     linewidth=linewidth,
                                      zorder=20,
                                      clip_on=False))
                      
@@ -225,6 +230,7 @@ def barscatter(data, transpose = False, unequal=False,
                          linewidth=linewidth,
                          markerfacecolor = scf,
                          markeredgecolor = sce,
+                         markeredgewidth=linewidth,
                          zorder=20,
                          clip_on=False))
     elif grouped == False:
@@ -235,6 +241,7 @@ def barscatter(data, transpose = False, unequal=False,
                          linewidth=linewidth,
                          markerfacecolor = scfacecolorArray[0],
                          markeredgecolor = scedgecolorArray[0],
+                         markeredgewidth=linewidth,
                          zorder=20,
                          clip_on=False))
     
@@ -249,7 +256,9 @@ def barscatter(data, transpose = False, unequal=False,
     if yaxisparams != 'auto':
         ax.set_ylim(yaxisparams[0])
         ax.set_yticks(yaxisparams[1])
-       
+        
+    ax.yaxis.set_tick_params(width=linewidth)
+
     # X ticks
     ax.tick_params(
         axis='x',          # changes apply to the x-axis
@@ -295,6 +304,9 @@ def barscatter(data, transpose = False, unequal=False,
     ax.spines['right'].set_visible(False)
     ax.spines['top'].set_visible(False)
     ax.spines['bottom'].set_position('zero')
+
+    ax.spines['bottom'].set_lw(linewidth)
+    ax.spines['left'].set_lw(linewidth)
     
     if show_legend == 'within':
         if len(itemlabel) != barspergroup:
@@ -307,6 +319,8 @@ def barscatter(data, transpose = False, unequal=False,
                 legendtext.append(itemlabel[i])
             ax.legend(legendbar, legendtext, loc=legendloc)
     
+    
+    
     return ax, barx, barlist, sclist
       
 def setcolors(coloroption, colors, barspergroup, nGroups, data, paired_scatter = False):
@@ -353,13 +367,13 @@ def setcolors(coloroption, colors, barspergroup, nGroups, data, paired_scatter =
     return coloroutput
 
 def data2obj1D(data):
-    obj = np.empty(len(data), dtype=np.object)
+    obj = np.empty(len(data), dtype=object)
     for i,x in enumerate(data):
         obj[i] = np.array(x)  
     return obj
 
 def data2obj2D(data):
-    obj = np.empty((np.shape(data)[0], np.shape(data)[1]), dtype=np.object)
+    obj = np.empty((np.shape(data)[0], np.shape(data)[1]), dtype=object)
     for i,x in enumerate(data):
         for j,y in enumerate(x):
             obj[i][j] = np.array(y)
@@ -385,3 +399,6 @@ def xyspacer(ax, x, yvals, bindist=20, space=0.1):
     yvals = np.sort(yvals)
 
     return xvals, yvals
+
+if __name__ == "__main__":
+    barscatter([[1, 2, 3, 4], [5, 6, 7, 8]], paired=True)
\ No newline at end of file
